@@ -1,4 +1,5 @@
 
+import logging
 import pathlib
 from datetime import datetime
 from functools import cached_property, partial
@@ -12,6 +13,9 @@ from aio.api.github import exceptions, interface, utils
 from . import base
 
 
+logger = logging.getLogger(__name__)
+
+
 class AGithubRepo(metaclass=abstracts.Abstraction):
     """A Github repo."""
 
@@ -61,16 +65,29 @@ class AGithubRepo(metaclass=abstracts.Abstraction):
 
     async def create_release(
             self,
-            branch: str,
-            tag_name: str) -> Dict[str, str | Dict]:
-        if await self.tag_exists(tag_name):
+            commitish: str,
+            tag_name: str,
+            dry_run: bool = False,
+            body: Optional[str] = None,
+            latest: Optional[bool] = False,
+            generate_release_notes: Optional[bool] = False) -> (
+                "interface.IGithubRelease"):
+        if await self.tag_exists(tag_name) and not dry_run:
             raise exceptions.TagExistsError(
                 f"Cannot create tag, already exists: {tag_name}")
-        return await self.post(
-            "releases",
-            dict(tag_name=tag_name,
-                 name=tag_name,
-                 target_commitish=branch))
+        url_vars: Dict[str, bool | str] = dict(
+            tag_name=tag_name,
+            name=tag_name,
+            target_commitish=commitish,
+            make_latest=("true" if latest else "false"))
+        if body is not None:
+            url_vars["body"] = body
+        if generate_release_notes is not None:
+            url_vars["generate_release_notes"] = generate_release_notes
+        logger.debug(
+            f"Create {'DRY RUN ' if dry_run else ''}release "
+            f"({tag_name}):\n  {url_vars}")
+        return await self.release(tag_name, url_vars, dry_run=dry_run)
 
     async def getitem(self, query: str) -> Any:
         """Call the `gidgethub.getitem` api for this repo."""
@@ -83,7 +100,10 @@ class AGithubRepo(metaclass=abstracts.Abstraction):
 
     def github_endpoint(self, rel_path: str) -> str:
         """Github API path for provided relative path."""
-        return str(self.github_path.joinpath(rel_path))
+        return (
+            rel_path
+            if rel_path.startswith("https://")
+            else str(self.github_path.joinpath(rel_path)))
 
     async def highest_release(
             self,
@@ -126,7 +146,13 @@ class AGithubRepo(metaclass=abstracts.Abstraction):
             data=data,
             **kwargs)
 
-    async def release(self, name: str) -> "interface.IGithubRelease":
+    async def release(
+            self,
+            name: str,
+            data: dict = None,
+            dry_run: bool = False) -> "interface.IGithubRelease":
+        if data:
+            return await self.github.release_class.create(self, data, dry_run)
         return self.github.release_class(
             self,
             await self.getitem(f"releases/tags/{name}"))
